@@ -2,7 +2,7 @@
 # housekeeping
 #######################################################################
 
-package Object::Exercise    v3.1.0;
+package Object::Exercise;
 use v5.20;
 
 use Symbol qw( qualify qualify_to_ref );
@@ -13,6 +13,9 @@ use Object::Exercise::Execute;
 # package variables
 ########################################################################
 
+our $VERSION    = '3.00';
+$VERSION        = eval "$VERSION";
+
 ########################################################################
 # subroutines
 ########################################################################
@@ -140,9 +143,10 @@ for method calls.
 
         q{noverbose}
 
-        # turn on elapsed and wallclock time output.
+        # turn on/off a breakpoint prior to execution or if the
+        # next step returns an error.
 
-        q{benchmark},
+        ...
 
         # set a breakpoint via $DB::single = 1 prior to calling
         # $object->$method for all following tests.
@@ -314,13 +318,6 @@ the method. The line following this breakpoint is:
 
 which can be used to immediately check why a call failed.
 
-=item counter (default 0)
-
-Outputs a ++n counter from 1 .. number of steps. Turning
-this on allows tracking total steps run for progressive
-execution (e.g., when noplan is used for testing multiple
-objects).
-
 =back
 
 =head1 Exercising Objects
