@@ -2,9 +2,10 @@
 # housekeeping
 #######################################################################
 
-package Object::Exercise::Execute   v3.1.1;
+package Object::Exercise::Execute;
 use v5.20;
 no warnings;
+use experimental    qw( autoderef );
 
 use Carp;
 
@@ -21,11 +22,13 @@ use Test::More;
 
 our @CARP_NOT   = ( __PACKAGE__ );
 
+our $VERSION    = '3.00';
+$VERSION        = eval "$VERSION";
+
 my @defaultz =
 qw
 (
     benchmark   0
-    counter     0
     break       0
     regex       0
 
@@ -67,7 +70,7 @@ sub extract_flags
         exists $globalz{ $name }
         or do
         {
-            diag "Unknown option: '$_'";
+            note "$_";
             next
         };
 
@@ -115,13 +118,12 @@ my $execute
     state $r    = [];
     state $t0   = '';
     state $t1   = '';
-    state $n    = 0;
 
     my ( $obj, $test ) = @_;
 
     my ( $method, @argz ) = @$test;
 
-    # assume that "@$r =" is not significant in the benchmark.
+    # assume that "$return =" is not significant in the benchmark.
     # also assume that nothing in gettimeofday will set $@.
 
     @$r = ();
@@ -136,23 +138,18 @@ my $execute
     };
     chomp( my $error = $@ );
 
-    if( $globalz{ counter   } )
-    {
-        note 'Instruction: ' . ++$n;
-    }
-
     if( $globalz{ benchmark } )
     {
         state $format   = "Benchmark: %0.6f sec\t%s( %s )";
 
         my $wall        = tv_interval $t0, $t1;
 
-        note sprintf $format => $wall, $method, explain @argz;
+        diag sprintf $format => $wall, $method, explain @argz;
     }
 
     if( $error )
     {
-        diag "Error: '$method'\n", explain $error;
+        note "Error: '$method'\n", explain $error;
     }
     elsif( $globalz{ verbose } )
     {
@@ -161,9 +158,6 @@ my $execute
 
     if( $error && $globalz{ debug } )
     {
-        # stop here where the error is visible and the
-        # test contents are still in scope.
-
         $DB::single = 1;
         0
     }
@@ -266,7 +260,7 @@ my $process
         return
     }
 
-    local @globalz{ keys %$localz } = values %$localz
+    local @globalz{ keys $localz } = values $localz
     if $localz;
 
     # if there is no expect value then skip the ok check and just
